==> sherpa-client-0.9.18.tar.gz: sherpa-client-0.9.18/sherpa_client/api/groups/get_groups.py <==
from typing import Any, Dict, List, Optional

import httpx

from ...client import Client
from ...models.group_desc import GroupDesc
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/groups".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[GroupDesc]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_group_desc_array_item_data in _response_200:
            componentsschemas_group_desc_array_item = GroupDesc.from_dict(componentsschemas_group_desc_array_item_data)

            response_200.append(componentsschemas_group_desc_array_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[List[GroupDesc]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[List[GroupDesc]]:
    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.get(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[List[GroupDesc]]:
    """ """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[List[GroupDesc]]:
    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[List[GroupDesc]]:
    """ """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed

==> sherpa-client-0.10.5.tar.gz: sherpa-client-0.10.5/sherpa_client/api/groups/get_groups.py <==
from typing import Any, Dict, List, Optional

import httpx

from ...client import Client
from ...models.group_desc import GroupDesc
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/groups".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[List[GroupDesc]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_group_desc_array_item_data in _response_200:
            componentsschemas_group_desc_array_item = GroupDesc.from_dict(componentsschemas_group_desc_array_item_data)

            response_200.append(componentsschemas_group_desc_array_item)

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[List[GroupDesc]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
) -> Response[List[GroupDesc]]:
    """Get users' groups

    Returns:
        Response[List[GroupDesc]]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
) -> Optional[List[GroupDesc]]:
    """Get users' groups

    Returns:
        Response[List[GroupDesc]]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
) -> Response[List[GroupDesc]]:
    """Get users' groups

    Returns:
        Response[List[GroupDesc]]
    """

    kwargs = _get_kwargs(
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
) -> Optional[List[GroupDesc]]:
    """Get users' groups

    Returns:
        Response[List[GroupDesc]]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed
